@@ -1,6 +1,6 @@
 
 # -*- coding: utf-8 -*-
-# Copyright 2017 - 2020 Avram Lubkin, All Rights Reserved
+# Copyright 2017 - 2022 Avram Lubkin, All Rights Reserved
 
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -19,10 +19,17 @@ import re
 import sys
 import warnings
 
-from blessed.colorspace import RGB_256TABLE
+from blessed.colorspace import RGB_256TABLE, X11_COLORNAMES_TO_RGB
 from blessed.sequences import iter_parse
 
 
+try:
+    from functools import lru_cache
+except ImportError:  # pragma: no cover(Python 2)
+    # lru_cache was added in Python 3.2
+    from backports.functools_lru_cache import lru_cache
+
+
 try:
     BASESTRING = basestring
 except NameError:
@@ -136,25 +143,23 @@ class Lookahead:
         return self
 
     def __next__(self):
-        if self.buffer:
-            return self.buffer.pop(0)
-        return next(self.iterator)
+        return self.buffer.pop(0) if self.buffer else next(self.iterator)
 
     # Python 2
     next = __next__
 
-    def lookahead(self, start, stop=None):
-        """
-        Args:
-            start(int): Positive integer index of first value
-            stop(int): Positive integer index to end before (not returned)
+    def __getitem__(self, key):
 
-        Retrieve next value(s) in iterator.
+        if isinstance(key, int):
+            first = last = key
+        elif isinstance(key, slice):
+            first = key.start or 0
+            last = max(first, (key.stop or 0) - 1)
+        else:
+            raise TypeError('Index or slice notation is required')
 
-        start and stop roughly behave like slice notation, but must be positive
-        """
-
-        last = max(start, (stop or 0) - 1)
+        if first < 0:
+            raise ValueError('Negative indexes are not supported')
 
         while last >= len(self.buffer):
             try:
@@ -162,10 +167,7 @@ class Lookahead:
             except StopIteration:
                 break
 
-        if stop is None:
-            return self.buffer[start]
-
-        return self.buffer[start:stop]
+        return self.buffer.__getitem__(key)
 
 
 class Span(list):
@@ -269,8 +271,7 @@ class HTMLConverter(object):
             last_added = to_out[-1] if to_out else None
 
             # Look for normal to close span
-            if value == normal[0] and \
-               normal[1:] == [val[0] for val in parsed.lookahead(0, self.normal_rem or None)]:
+            if value == normal[0] and normal[1:] == [val[0] for val in parsed[: self.normal_rem]]:
 
                 # Clear rest of normal
                 for _ in range(self.normal_rem):
@@ -323,6 +324,38 @@ class HTMLConverter(object):
             4: ('enlighten-underline', {'text-decoration': 'underline'}),
         }
 
+    @property
+    @lru_cache()
+    def rgb_to_colors(self):
+        """
+        Dictionary for translating known RGB values into X11 names
+        """
+
+        rtn = {}
+        for key, val in sorted(X11_COLORNAMES_TO_RGB.items()):
+            val = '#%02x%02x%02x' % val
+            if val not in rtn:
+                rtn[val] = key
+
+        return rtn
+
+    def _color256_lookup(self, idx):
+        """
+        Look up RGB values and attempt to get names in the 256 color space
+        """
+
+        rgb = str(RGB_256TABLE[idx])
+
+        # Some terminals use 256 color syntax for basic colors
+        if 0 <= idx <= 7:  # pragma: no cover(Non-standard Terminal)
+            name = CGA_COLORS[idx]
+        elif 8 <= idx <= 15:  # pragma: no cover(Non-standard Terminal)
+            name = 'bright-%s' % CGA_COLORS[idx - 8]
+        else:
+            name = self.rgb_to_colors.get((rgb[1:3], rgb[3:5], rgb[5:7]), rgb[1:])
+        return name, rgb
+
+    @lru_cache(maxsize=256)
     def _parse_style(self, value, cap):  # pylint: disable=too-many-return-statements
         r"""
         Args:
@@ -337,12 +370,14 @@ class HTMLConverter(object):
         # Parse RGB color foreground
         if cap is caps['color_rgb']:
             rgb = '#%02x%02x%02x' % tuple(int(num) for num in RE_COLOR_RGB.match(value).groups())
-            return 'enlighten-fg-%s' % rgb[1:], {'color': rgb}
+            name = self.rgb_to_colors.get(rgb, rgb[1:])
+            return 'enlighten-fg-%s' % name, {'color': rgb}
 
         # Parse RGB color background
         if cap is caps['on_color_rgb']:
             rgb = '#%02x%02x%02x' % tuple(int(num) for num in RE_ON_COLOR_RGB.match(value).groups())
-            return 'enlighten-bg-%s' % rgb[1:], {'background-color': rgb}
+            name = self.rgb_to_colors.get(rgb, rgb[1:])
+            return 'enlighten-bg-%s' % name, {'background-color': rgb}
 
         # Weird and inconsistent bug that seems to affect Python <= 3.5
         # Matches set_a_attributes3 instead of more specific color 256 patterns
@@ -354,13 +389,13 @@ class HTMLConverter(object):
 
         # Parse 256 color foreground
         if cap is caps['color256']:
-            rgb = str(RGB_256TABLE[int(RE_COLOR_256.match(value).group(1))])
-            return 'enlighten-fg-%s' % rgb[1:], {'color': rgb}
+            name, rgb = self._color256_lookup(int(RE_COLOR_256.match(value).group(1)))
+            return 'enlighten-fg-%s' % name, {'color': rgb}
 
         # Parse 256 color background
         if cap is caps['on_color256']:
-            rgb = str(RGB_256TABLE[int(RE_ON_COLOR_256.match(value).group(1))])
-            return 'enlighten-bg-%s' % rgb[1:], {'background-color': rgb}
+            name, rgb = self._color256_lookup(int(RE_ON_COLOR_256.match(value).group(1)))
+            return 'enlighten-bg-%s' % name, {'background-color': rgb}
 
         # Parse text attributes
         if cap is caps['set_a_attributes1']:
