@@ -1,4 +1,4 @@
-# Copyright 2019 - 2021 Avram Lubkin, All Rights Reserved
+# Copyright 2019 - 2022 Avram Lubkin, All Rights Reserved
 
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -105,7 +105,7 @@ def run_tests(manager, tests=100):
             if result == 7:
                 LOGGER.error("Test %d did not complete", num)
                 errors.update()
-            elif result in (5, 6):
+            elif result in {5, 6}:
                 LOGGER.error("Test %d failed", num)
                 failures.update()
             else:
