@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2017 - 2021 Avram Lubkin, All Rights Reserved
+# Copyright 2017 - 2022 Avram Lubkin, All Rights Reserved
 
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -24,6 +24,7 @@ TERMINAL = 'blessed.Terminal'
 
 
 # pylint: disable=missing-docstring, protected-access, too-many-statements, too-many-public-methods
+# pylint: disable=too-many-lines
 
 class TestManager(TestCase):
 
@@ -38,20 +39,23 @@ class TestManager(TestCase):
     def test_init_safe(self):
         with redirect_output('stdout', self.tty.stdout):
             # Companion stream is stderr if stream is stdout
-            manager = enlighten.Manager()
+            manager = enlighten.Manager(stream=sys.stdout)
             self.assertIs(manager.stream, sys.stdout)
             self.assertIs(manager.term.stream, sys.stdout)
 
     @unittest.skipIf(STDOUT_NO_FD, 'No file descriptor for stdout')
     def test_init(self):
-        # Companion stream is stderr if stream is stdout
-        manager = enlighten.Manager()
-        self.assertIs(manager.stream, sys.stdout)
-        self.assertIs(manager.term.stream, sys.stdout)
-        # This will fail building rpm packages since stderr is redirected
-        if sys.__stderr__.isatty():
-            self.assertIs(manager.companion_stream, sys.__stderr__)
-            self.assertIs(manager.companion_term.stream, sys.__stderr__)
+        # Companion stream is __stderr__ if stream is __stdout__
+
+        # Need to mock isatty() for some build and test environments
+        with mock.patch.object(sys, '__stderr__') as mock_stderr:
+            mock_stderr.isatty.return_value = True
+            manager = enlighten.Manager(stream=sys.__stdout__)
+
+        self.assertIs(manager.stream, sys.__stdout__)
+        self.assertIs(manager.term.stream, sys.__stdout__)
+        self.assertIs(manager.companion_stream, mock_stderr)
+        self.assertIs(manager.companion_term.stream, mock_stderr)
 
     @unittest.skipIf(STDOUT_NO_FD, 'No file descriptor for stdout')
     def test_init_companion_hc(self):
@@ -62,38 +66,47 @@ class TestManager(TestCase):
 
     @unittest.skipIf(STDOUT_NO_FD, 'No file descriptor for stdout')
     def test_init_stderr(self):
-        # Companion stream is stdout if stream is stderr
-        manager = enlighten.Manager(stream=sys.__stderr__)
+        # Companion stream is __stdout__ if stream is __stderr__
+
+        # Need to mock isatty() for some build and test environments
+        with mock.patch.object(sys, '__stdout__') as mock_stdout:
+            mock_stdout.isatty.return_value = True
+            manager = enlighten.Manager(stream=sys.__stderr__)
+
         self.assertIs(manager.stream, sys.__stderr__)
         self.assertIs(manager.term.stream, sys.__stderr__)
-        # This will fail building rpm packages since stderr is redirected
-        if sys.__stdout__.isatty():
-            self.assertIs(manager.companion_stream, sys.__stdout__)
-            self.assertIs(manager.companion_term.stream, sys.__stdout__)
+        self.assertIs(manager.companion_stream, mock_stdout)
+        self.assertIs(manager.companion_term.stream, mock_stdout)
 
     @unittest.skipIf(STDOUT_NO_FD, 'No file descriptor for stdout')
     def test_init_redirect(self):
         # If stdout is redirected, but stderr is still a tty, use it for companion
         with redirect_output('stdout', OUTPUT):
-            manager = enlighten.Manager()
+
+            # Need to mock isatty() for some build and test environments
+            with mock.patch.object(sys, 'stderr') as mock_stderr:
+                mock_stderr.isatty.return_value = True
+                manager = enlighten.Manager(stream=sys.stdout)
+
             self.assertIs(manager.stream, sys.stdout)
             self.assertIs(manager.term.stream, sys.stdout)
-            # This will fail building rpm packages since stderr is redirected
-            if sys.__stderr__.isatty():
-                self.assertIs(manager.companion_stream, sys.stderr)
-                self.assertIs(manager.companion_term.stream, sys.stderr)
+            self.assertIs(manager.companion_stream, mock_stderr)
+            self.assertIs(manager.companion_term.stream, mock_stderr)
 
     @unittest.skipIf(STDOUT_NO_FD, 'No file descriptor for stdout')
     def test_init_stderr_redirect(self):
         # If stderr is redirected, but stdout is still a tty, use it for companion
         with redirect_output('stderr', OUTPUT):
-            manager = enlighten.Manager(stream=sys.stderr)
+
+            # Need to mock isatty() for some build and test environments
+            with mock.patch.object(sys, 'stdout') as mock_stdout:
+                mock_stdout.isatty.return_value = True
+                manager = enlighten.Manager(stream=sys.stderr)
+
             self.assertIs(manager.stream, sys.stderr)
             self.assertIs(manager.term.stream, sys.stderr)
-            # This will fail building rpm packages since stderr is redirected
-            if sys.__stdout__.isatty():
-                self.assertIs(manager.companion_stream, sys.stdout)
-                self.assertIs(manager.companion_term.stream, sys.stdout)
+            self.assertIs(manager.companion_stream, mock_stdout)
+            self.assertIs(manager.companion_term.stream, mock_stdout)
 
     @unittest.skipIf(STDOUT_NO_FD, 'No file descriptor for stdout')
     def test_init_stderr_companion_hc(self):
@@ -123,7 +136,7 @@ class TestManager(TestCase):
 
     def test_repr(self):
         manager = enlighten.Manager()
-        self.assertEqual(repr(manager), "Manager(stream=%r)" % sys.stdout)
+        self.assertEqual(repr(manager), "Manager(stream=%r)" % sys.__stdout__)
 
     def test_counter_and_remove(self):
         # pylint: disable=no-member,assigning-non-slot
@@ -356,7 +369,7 @@ class TestManager(TestCase):
         # Counter 1 in auto-refresh list
         self.assertIn(counter1, manager.autorefresh)
 
-        # If auto-refreshed counter hasn't been refreshed recently refresh
+        # If auto-refreshed counter hasn't been refreshed recently, refresh
         counter1.last_update = 0
         counter2.refresh()
         self.tty.stdout.write(u'X\n')
@@ -973,8 +986,8 @@ class TestGetManager(TestCase):
     def test_get_manager_tty(self):
 
         # stdout is attached to a tty
-        with redirect_output('stdout', self.tty.stdout):
-            self.assertTrue(sys.stdout.isatty())
+        with redirect_output('__stdout__', self.tty.stdout):
+            self.assertTrue(sys.__stdout__.isatty())
             manager = enlighten.get_manager(unit='knights')
             self.assertIsInstance(manager, _manager.Manager)
             self.assertTrue('unit' in manager.defaults)
@@ -986,8 +999,8 @@ class TestGetManager(TestCase):
     def test_get_manager_no_tty(self):
 
         # stdout is not attached to a tty
-        with redirect_output('stdout', OUTPUT):
-            self.assertFalse(sys.stdout.isatty())
+        with redirect_output('__stdout__', OUTPUT):
+            self.assertFalse(sys.__stdout__.isatty())
             manager = enlighten.get_manager(unit='knights')
             self.assertIsInstance(manager, _manager.Manager)
             self.assertTrue('unit' in manager.defaults)
