@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2021 Avram Lubkin, All Rights Reserved
+# Copyright 2021 - 2023 Avram Lubkin, All Rights Reserved
 
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -97,5 +97,8 @@ class TestNotebookManager(TestCase):
         # test_styles: should have output
         self.assertTrue(has_html_output(notebook.cells[6]), 'display_data not found in outputs')
 
+        # test_stop_no_counters: should have output
+        self.assertTrue(has_html_output(notebook.cells[7]), 'display_data not found in outputs')
+
         # Cleanup: should have no output
-        self.assertFalse(notebook.cells[7].outputs)
+        self.assertFalse(notebook.cells[8].outputs)
